using Microsoft.OpenApi.Models;
using Swashbuckle.AspNetCore.SwaggerGen;

namespace cuqmbr.TravelGuide.HttpApi.Swashbuckle.OperationFilters;

public class AcceptTimeZoneHeaderOperationFilter : IOperationFilter
{
    public void Apply(OpenApiOperation operation, OperationFilterContext context)
    {
        // TODO: Remove security requirements
        operation.Security ??= new List<OpenApiSecurityRequirement>();

        var acceptTimeZone = new OpenApiSecurityScheme
        {
            Reference = new OpenApiReference
            {
                Type = ReferenceType.SecurityScheme,
                Id = "Accept-TimeZone"
            }
        };

        operation.Security.Add(new OpenApiSecurityRequirement
        {
            [acceptTimeZone] = new List<string>()
        });

        if (operation.Parameters == null)
            operation.Parameters = new List<OpenApiParameter>();

        operation.Parameters.Add(new OpenApiParameter
        {
            Name = "Accept-TimeZone",
            Description = "Format: \\<Region\\>/\\<City\\>. Time Zone name " +
                "from IANA tz database (https://www.iana.org/time-zones).",
            In = ParameterLocation.Header,
            Schema = new OpenApiSchema { Type = "String" },
            Required = false
        });
    }
}
