using cuqmbr.TravelGuide.Domain.Entities;
using cuqmbr.TravelGuide.Domain.Enums;
using Microsoft.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore.Metadata.Builders;

namespace cuqmbr.TravelGuide.Persistence.PostgreSql.Configurations;

public class RouteConfiguration : BaseConfiguration<Route>
{
    public override void Configure(EntityTypeBuilder<Route> builder)
    {
        builder
            .Property(r => r.VehicleType)
            .HasColumnName("vehicle_type")
            .HasColumnType("varchar(16)")
            .IsRequired(true);

        builder
            .ToTable(
                "routes",
                r => r.HasCheckConstraint(
                    "ck_" +
                    $"{builder.Metadata.GetTableName()}_" +
                    $"{builder.Property(a => a.VehicleType)
                        .Metadata.GetColumnName()}",
                    $"{builder.Property(a => a.VehicleType)
                        .Metadata.GetColumnName()} IN ('{String
                        .Join("', '", VehicleType.Enumerations
                            .Values.Select(v => v.Name))}')"));

        base.Configure(builder);


        builder
            .Property(r => r.Name)
            .HasColumnName("name")
            .HasColumnType("varchar(64)")
            .IsRequired(true);
    }
}
